@@ -37,6 +37,7 @@
 // User interface
 #include "as_gui.h"             // Main classes
 #include "as_tableitem.h"       // For class RtTableItem
+#include "as_crc.h"             // For quality strings
 
 // Icon pixel maps
 #include "as_gfx/statok.xpm"    // static const char *s_kpcStatokay_xpm[]
@@ -139,7 +140,6 @@ void Titraqform::loadData(QTextStream &Tstream)
     bool bValid = true; // Used to warn on globally invalid accounting data
     int nIter = 0;      // Iterator used in loop and also as a count
     QString Line;       // Used for linewise editing and whitespace eating
-    QString Parstring;  // Used to parse all extra '-' and '=' token delimiters
     QString Bitbucket;  // Used for null device until we find a better way
 
     QPixmap Statokay(s_kpcStatokay_xpm);
@@ -201,7 +201,6 @@ void Titraqform::loadData(QTextStream &Tstream)
         bool bValid = true; // Warns on linewise invalid accounting data
         QString User, Guid, Crc, Rev;                           // Valid admin fields
         QString Date, Start, Finish, Account, Amount, Remark;   // Valid user fields
-        QString Timepack;                       // Packed start finish amount field
         QTextStream Asline(&Line, IO_ReadOnly); // Convert a single line now
 
         if (nIter % g_knBlocks == 0) // Add blocks of rows to optimize loading
@@ -223,10 +222,7 @@ void Titraqform::loadData(QTextStream &Tstream)
 
         Asline.skipWhiteSpace();    // Remove whitespaces
         Asline >> Crc;              // Copy the CRC field
-        if (!Crc.isEmpty())
-            m_pMaintable->setText(nIter, TITRAQ_IDXCRC, Crc);
-        else
-            bValid = false;
+        // Postpone actual text delivery, to autoinsert CRCs!
 
         Asline.skipWhiteSpace();    // Remove whitespaces
         Asline >> Rev;              // Copy the rev field
@@ -237,41 +233,29 @@ void Titraqform::loadData(QTextStream &Tstream)
 
         Asline.skipWhiteSpace();    // Remove whitespaces
         Asline >> Date;             // Copy the date field
-        if (!Date.isEmpty()) {
-            Date.insert(TITRAQ_OFFSETYEAR, QChar('.'));     // Format year
-            Date.insert(TITRAQ_OFFSETMONTH, QChar('.'));    // Format month
+        if (!Date.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXDATE, Date);
-        }
         else
             bValid = false;
 
         Asline.skipWhiteSpace();    // Remove whitespaces
-        Asline >> Timepack;
-
-        // Hack to hard code regex parsing logic into the document format
-        Start = Timepack.section('-', 0, 0, QString::SectionDefault);
-        Finish = Timepack.section('-', 1, 1, QString::SectionDefault);
-        Finish = Finish.section('=', 0, 0, QString::SectionDefault);
-        Amount = Timepack.section('=', 1, 1, QString::SectionDefault);
-
-        if (!Start.isEmpty()) {                             // Write start
-            Start.insert(TITRAQ_OFFSETHOUR, QChar(':'));    // Format hour
+        Asline >> Start;            // Copy the start field
+        if (!Start.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXSTART, Start);
-        }
         else
             bValid = false;
 
-        if (!Finish.isEmpty()) {                            // Write finish
-            Finish.insert(TITRAQ_OFFSETHOUR, QChar(':'));   // Format hour
+        Asline.skipWhiteSpace();    // Remove whitespaces
+        Asline >> Finish;           // Copy the finish field
+        if (!Finish.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXFINISH, Finish);
-        }
         else
             bValid = false;
 
-        if (!Amount.isEmpty()) {                            // Write amount
-            Amount.insert(TITRAQ_OFFSETHOUR, QChar(':'));   // Format hour
+        Asline.skipWhiteSpace();    // Remove whitespaces
+        Asline >> Amount;           // Copy the amount field
+        if (!Amount.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXAMOUNT, Amount);
-        }
         else
             bValid = false;
 
@@ -305,6 +289,21 @@ void Titraqform::loadData(QTextStream &Tstream)
             m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, Staterror);
         }
 
+        // Set the CRC text here, in case we need to generate a fresh value
+        if (!Crc.isEmpty()) {
+            if (Crc != ".") // This means, generate a fresh CRC value
+                m_pMaintable->setText(nIter, TITRAQ_IDXCRC, "0x" + Crc);
+            else {
+                // Make our long tuple to run through the CRC32 generator
+                Qualistring Testuple = User + Guid + Rev + Date + Start;
+                            Testuple += Finish + Amount + Account + Remark;
+                U32 Valcrc = Testuple.getCrc(); // Finally set the checksum to its new value
+                m_pMaintable->setText(nIter, TITRAQ_IDXCRC, "0x" + QString::number(Valcrc, 16));
+            }
+        }
+        else // if isEmpty()
+            bValid = false;
+
         nIter++;            // The big increment
         Line = QString(""); // Clear line for next round
 
@@ -379,6 +378,7 @@ void Titraqform::saveData(QTextStream &Tstream)
             Tstream << trUtf8(" ") << Tempfield;                    // Save GUID field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXCRC);       // Load CRC field text
+        Tempfield.remove("0x");
         if (Tempfield != NULL)
             Tstream << trUtf8(" ") << Tempfield;                    // Save CRC field text
 
@@ -387,26 +387,20 @@ void Titraqform::saveData(QTextStream &Tstream)
             Tstream << trUtf8(" ") << Tempfield;                    // Save rev field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXDATE);      // Load date field text
-        Tempfield.remove(QChar('.'));
         if (Tempfield != NULL)
             Tstream << trUtf8(" ") << Tempfield;                    // Save date field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXSTART);     // Load start field text
-        Tempfield.remove(QChar(':'));
         if (Tempfield != NULL)
             Tstream << trUtf8(" ") << Tempfield;                    // Save start field text
-        Tstream << trUtf8("-");                                     // Save start field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXFINISH);    // Load end field text
-        Tempfield.remove(QChar(':'));
         if (Tempfield != NULL)
-            Tstream << Tempfield;                                   // Save end field text
-        Tstream << trUtf8("=");                                     // Save start field text
+            Tstream << trUtf8(" ") << Tempfield;                    // Save end field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXAMOUNT);    // Load amount field text
-        Tempfield.remove(QChar(':'));
         if (Tempfield != NULL)
-            Tstream << Tempfield;                                   // Save amount field text
+            Tstream << trUtf8(" ") << Tempfield;                    // Save amount
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXTASK);      // Load acct field text
         if (Tempfield != NULL)
